@@ -72,6 +72,63 @@ void GameHeader::save(GAGCore::OutputStream *stream) const
 }
 
 
+
+bool GameHeader::loadWithoutPlayerInfo(GAGCore::InputStream *stream, Sint32 versionMinor)
+{
+	stream->readEnterSection("GameHeader");
+	gameLatency = stream->readSint32("gameLatency");
+	orderRate = stream->readUint8("orderRate");
+	stream->readLeaveSection();
+	return true;
+}
+
+
+
+void GameHeader::saveWithoutPlayerInfo(GAGCore::OutputStream *stream) const
+{
+	stream->writeEnterSection("GameHeader");
+	stream->writeSint32(gameLatency, "gameLatency");
+	stream->writeUint8(orderRate, "orderRate");
+	stream->writeLeaveSection();
+}
+
+
+
+bool GameHeader::loadPlayerInfo(GAGCore::InputStream *stream, Sint32 versionMinor)
+{
+	stream->readEnterSection("GameHeader");
+	numberOfPlayers = stream->readSint32("numberOfPlayers");
+	stream->readEnterSection("players");
+	for(int i=0; i<32; ++i)
+	{
+		stream->readEnterSection(i);
+		players[i].load(stream, versionMinor);
+		stream->readLeaveSection(i);
+	}
+	stream->readLeaveSection();
+	stream->readLeaveSection();
+	return true;
+}
+
+
+
+void GameHeader::savePlayerInfo(GAGCore::OutputStream *stream) const
+{
+	stream->writeEnterSection("GameHeader");
+	stream->writeSint32(numberOfPlayers, "numberOfPlayers");
+	stream->writeEnterSection("players");
+	for(int i=0; i<32; ++i)
+	{
+		stream->writeEnterSection(i);
+		players[i].save(stream);
+		stream->writeLeaveSection();
+	}
+	stream->writeLeaveSection();
+	stream->writeLeaveSection();
+}
+
+
+
 Sint32 GameHeader::getNumberOfPlayers() const
 {
 	return numberOfPlayers;
@@ -119,3 +176,12 @@ BasePlayer& GameHeader::getBasePlayer(const int n)
 	assert(n<32 && n>=0);
 	return players[n];
 }
+
+
+
+const BasePlayer& GameHeader::getBasePlayer(const int n) const
+{
+	assert(n<32 && n>=0);
+	return players[n];
+}
+
