@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -176,11 +176,6 @@ void MapGenerationDescriptor::save(GAGCore::OutputStream *stream)
 
 bool MapGenerationDescriptor::load(GAGCore::InputStream *stream, Sint32 versionMinor)
 {
-	if (versionMinor < 47)
-	{
-		std::cerr << "Error : map generation description of versionMinor lower than 47 can't be loaded" << std::endl;
-		return false;
-	}
 	stream->readEnterSection("MapGenerationDescriptor");
 	char signature[4];
 	stream->read(signature, 4, "signatureStart");
