@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -1010,6 +1010,7 @@ bool Map::makeRandomMap(MapGenerationDescriptor &descriptor)
 				case 0: fruit = CHERRY; break;
 				case 1: fruit = ORANGE; break;
 				case 2: fruit = PRUNE; break;
+				default: fruit = PRUNE; break;
 			}
 			//choose coordinate where there is grass but no ressource yet
 			int x, y;
@@ -1653,7 +1654,7 @@ bool Game::oldMakeIslandsMap(MapGenerationDescriptor &descriptor)
 {
 	for (int s=0; s<descriptor.nbTeams; s++)
 	{
-		if (session.numberOfTeam<=s)
+		if (mapHeader.getNumberOfTeams()<=s)
 			addTeam();
 		int squareSize=5+descriptor.oldIslandSize/10;
 		map.setUMatPos(descriptor.bootX[s]+2, descriptor.bootY[s]+0, GRASS, squareSize);
@@ -1687,8 +1688,8 @@ bool Game::makeRandomMap(MapGenerationDescriptor &descriptor)
 {
 	for (int s=0; s<descriptor.nbTeams; s++)
 	{
-		assert(session.numberOfTeam==s);
-		if (session.numberOfTeam<=s)
+		assert(mapHeader.getNumberOfTeams()==s);
+		if (mapHeader.getNumberOfTeams()<=s)
 			addTeam();
 		
 		map.setUMatPos(descriptor.bootX[s]+2, descriptor.bootY[s]+0, GRASS, 5);
@@ -1757,9 +1758,6 @@ bool Game::generateMap(MapGenerationDescriptor &descriptor)
 		default:
 			assert(false);
 	}
-	if (session.mapGenerationDescriptor)
-		delete session.mapGenerationDescriptor;
-	session.mapGenerationDescriptor=new MapGenerationDescriptor(descriptor);
 	
 	// compile script
 	script.compileScript(this);
